Package: celldex
Title: Index of Reference Cell Type Datasets
Version: 1.20.0
Date: 2024-04-25
Authors@R: c(person("Dvir", "Aran", email="dvir.aran@ucsf.edu", role=c("aut")),
    person("Aaron", "Lun", email="infinite.monkeys.with.keyboards@gmail.com", role=c("aut", "cre", "cph")),
    person("Daniel", "Bunis", role="aut"),
    person("Jared", "Andrews", email = "jared.andrews07@gmail.com", role="aut"),
    person("Friederike", "Dündar", email = "frd2007@med.cornell.edu", role="aut"))
Description: 
    Provides a collection of reference expression datasets with curated cell
    type labels, for use in procedures like automated annotation of single-cell
    data or deconvolution of bulk RNA-seq.
License: GPL-3
Depends: SummarizedExperiment
Imports: utils, methods, Matrix, ExperimentHub, AnnotationHub,
        AnnotationDbi, S4Vectors, DelayedArray, DelayedMatrixStats,
        gypsum, alabaster.base, alabaster.matrix, alabaster.se, DBI,
        RSQLite, jsonlite
Suggests: testthat, knitr, rmarkdown, BiocStyle, DT, jsonvalidate,
        BiocManager, ensembldb
biocViews: ExperimentHub, ExperimentData, ExpressionData,
        SequencingData, RNASeqData
VignetteBuilder: knitr
Encoding: UTF-8
URL: https://github.com/LTLA/celldex
BugReports: https://support.bioconductor.org/
RoxygenNote: 7.3.1
git_url: https://git.bioconductor.org/packages/celldex
git_branch: RELEASE_3_22
git_last_commit: 4db42c8
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 16:11:13 UTC; biocbuild
Author: Dvir Aran [aut],
  Aaron Lun [aut, cre, cph],
  Daniel Bunis [aut],
  Jared Andrews [aut],
  Friederike Dündar [aut]
Maintainer: Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>
