# Generated by roxygen2: do not edit by hand

export(BlueprintEncodeData)
export(DatabaseImmuneCellExpressionData)
export(HumanPrimaryCellAtlasData)
export(ImmGenData)
export(MonacoImmuneData)
export(MouseRNAseqData)
export(NovershternHematopoieticData)
export(defineTextQuery)
export(fetchLatestVersion)
export(fetchMetadata)
export(fetchReference)
export(listReferences)
export(listVersions)
export(saveReference)
export(searchReferences)
export(surveyReferences)
import(methods)
importClassesFrom(Matrix,dgCMatrix)
importClassesFrom(Matrix,lgCMatrix)
importClassesFrom(alabaster.matrix,ReloadedArray)
importFrom(AnnotationDbi,mapIds)
importFrom(AnnotationHub,AnnotationHub)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbGetQuery)
importFrom(DelayedArray,DelayedArray)
importFrom(DelayedArray,is_sparse)
importFrom(DelayedArray,type)
importFrom(DelayedMatrixStats,colAnyNAs)
importFrom(DelayedMatrixStats,rowAnyNAs)
importFrom(ExperimentHub,ExperimentHub)
importFrom(RSQLite,SQLite)
importFrom(S4Vectors,DataFrame)
importFrom(SummarizedExperiment,"assay<-")
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(alabaster.base,altReadObject)
importFrom(alabaster.base,altReadObjectFunction)
importFrom(alabaster.base,readObject)
importFrom(alabaster.base,readObjectFile)
importFrom(alabaster.base,saveObject)
importFrom(gypsum,cacheDirectory)
importFrom(gypsum,defineTextQuery)
importFrom(gypsum,fetchLatest)
importFrom(gypsum,fetchMetadataDatabase)
importFrom(gypsum,fetchMetadataSchema)
importFrom(gypsum,formatObjectMetadata)
importFrom(gypsum,listAssets)
importFrom(gypsum,saveFile)
importFrom(gypsum,saveVersion)
importFrom(gypsum,searchMetadataTextFilter)
importFrom(gypsum,validateMetadata)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(utils,read.delim)
importMethodsFrom(alabaster.se,saveObject)
